pecos.error\_models
===================

.. automodule:: pecos.error_models



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.error_models.class_errors_circuit
   pecos.error_models.depolarizing_error_model
   pecos.error_models.error_depolar
   pecos.error_models.error_model
   pecos.error_models.error_model_abc
   pecos.error_models.fake_error_model
   pecos.error_models.generic_error_model
   pecos.error_models.noise_impl
   pecos.error_models.noise_impl_old
   pecos.error_models.old
   pecos.error_models.parent_class_error_gen
   pecos.error_models.simple_depolarizing_error_model
